@@ -354,8 +354,8 @@ impl GeneralReadout for LinuxGeneralReadout {
         Ok(extra::pop_newline(terminal))
     }
 
-    fn shell(&self, format: ShellFormat) -> Result<String, ReadoutError> {
-        crate::shared::shell(format)
+    fn shell(&self, format: ShellFormat, kind: ShellKind) -> Result<String, ReadoutError> {
+        crate::shared::shell(format, kind)
     }
 
     fn gpus(&self) -> Result<Vec<String>, ReadoutError> {
